# knn_fishmlserv




# command
```bash
물고기의 길이를 입력하세요: 33
물고기의 무게를 입력하세요: 33
이 녀석은 바로 도미
정답을 입력하세요: 도미
물고기의 길이를 입력하세요: 22
물고기의 무게를 입력하세요: 22
이 녀석은 바로 도미
정답을 입력하세요: 도미
나가기를 원하면 'exit'를 입력하세요: exit
```

